# ElSabio

*Wisdom from integrated energy data*

ElSabio (*el sabio* means *the wise* in Spanish) is **the simple electricity meter data analysis platform**.
It helps you unlock insights hidden in your meter data. Use it to understand your grid and customers better
to ultimately make smarter decisions.

Built with utilities in mind, ElSabio is:

- ✅ **Simple** – intuitive and easy to use,

- 🔄 **Adaptable** – flexible to new market requirements and organizational needs,

- ⚡ **Powerful** – built with the goal of supporting complex, real-world grid analytics as the project evolves.

⚠️ **Note:** *ElSabio is still under active development and not yet ready for production use.*


## Why ElSabio?

**Usage, grid and customers — united for insight**

Utility companies face growing demands for transparency, efficiency, and adaptability in their day to day operations.
ElSabio unlocks insights by combining three key perspectives:

- 📈 **Meter data** – covering consumption and production patterns as well as operational signals like meter events and alarms,

- 🕸 **Grid topology** – showing how assets are organized and related to customers,

- 👥 **Customer information** – highlighting how different customer and asset groups use and interact with the grid.

By bringing these perspectives together ElSabio enables blending this data into actionable insights.
This integrated view helps utilities design fairer tariffs, understand the impact on different customer groups
and forecast income with greater accuracy. It also makes it possible to act on grid faults before customers notice.


## License

ElSabio is distributed under the [GNU General Public License v3.0](https://www.gnu.org/licenses/gpl-3.0-standalone.html).
